@@ -1,6 +1,7 @@
 from django.contrib.postgres.fields import JSONField
 # from django.db.models import JSONField
 from django.db.models import CharField
+
 from isc_common.fields import Field
 
 
@@ -20,6 +21,7 @@ class CodeField(CharField, Field):
         del kwargs['default']
         return name, path, args, kwargs
 
+
 class CodeStrictField(CharField, Field):
     def __init__(self, *args, **kwargs):
         kwargs.setdefault('max_length', 255)
@@ -34,6 +36,7 @@ class CodeStrictField(CharField, Field):
         del kwargs['default']
         return name, path, args, kwargs
 
+
 class ColorField(CharField, Field):
     def __init__(self, *args, **kwargs):
         kwargs.setdefault('max_length', 10)
@@ -48,5 +51,8 @@ class ColorField(CharField, Field):
         del kwargs['default']
         return name, path, args, kwargs
 
-class JSONFieldIVC (JSONField):
-    pass
+
+class JSONFieldIVC(JSONField):
+    def __init__(self, *args, **kwargs):
+        kwargs.setdefault('default', dict)
+        super().__init__(*args, **kwargs)
